[![Build Status](https://travis-ci.org/Moguri/panda3d-blend2bam.svg?branch=master)](https://travis-ci.org/Moguri/panda3d-blend2bam)
<!--[![](https://img.shields.io/pypi/pyversions/panda3d-blend2bam.svg)](https://pypi.org/project/panda3d-blend2bam/)-->
[![Panda3D Versions](https://img.shields.io/badge/panda3d-1.9%2C%201.10-blue.svg)](https://www.panda3d.org/)
[![](https://img.shields.io/github/license/Moguri/panda3d-blend2bam.svg)](https://choosealicense.com/licenses/mit/)


# blend2bam
`blend2bam` is a CLI tool to convert Blender blend files to Panda3D BAM files


## Installation

Use [pip](https://github.com/panda3d/panda3d) to install the panda3d-blend2bam package:

```bash
pip install panda3d-blend2bam
```

## Usage

```bash
blend2bam input.blend output.bam
```

## License

[MIT](https://choosealicense.com/licenses/mit/)
